"use strict";

export let TemporaryStorageOption = /*#__PURE__*/function (TemporaryStorageOption) {
  TemporaryStorageOption["MEMORY"] = "memory";
  TemporaryStorageOption["FILESYSTEM"] = "file";
  return TemporaryStorageOption;
}({});

// SQLite journal mode. Set on the primary connection.
// This library is written with WAL mode in mind - other modes may cause
// unexpected locking behavior.
var SqliteJournalMode = /*#__PURE__*/function (SqliteJournalMode) {
  // Use a write-ahead log instead of a rollback journal.
  // This provides good performance and concurrency.
  SqliteJournalMode["wal"] = "WAL";
  SqliteJournalMode["delete"] = "DELETE";
  SqliteJournalMode["truncate"] = "TRUNCATE";
  SqliteJournalMode["persist"] = "PERSIST";
  SqliteJournalMode["memory"] = "MEMORY";
  SqliteJournalMode["off"] = "OFF";
  return SqliteJournalMode;
}(SqliteJournalMode || {}); // SQLite file commit mode.
var SqliteSynchronous = /*#__PURE__*/function (SqliteSynchronous) {
  SqliteSynchronous["normal"] = "NORMAL";
  SqliteSynchronous["full"] = "FULL";
  SqliteSynchronous["off"] = "OFF";
  return SqliteSynchronous;
}(SqliteSynchronous || {});
export const DEFAULT_SQLITE_OPTIONS = {
  journalMode: SqliteJournalMode.wal,
  synchronous: SqliteSynchronous.normal,
  journalSizeLimit: 6 * 1024 * 1024,
  cacheSizeKb: 50 * 1024,
  temporaryStorage: TemporaryStorageOption.MEMORY,
  lockTimeoutMs: 30000,
  encryptionKey: null,
  extensions: []
};
//# sourceMappingURL=SqliteOptions.js.map