import { BaseObserver, DBAdapter, DBAdapterListener, DBLockOptions, QueryResult, Transaction } from '@powersync/common';
import Lock from 'async-lock';
import { OPSQLiteConnection } from './OPSQLiteConnection';
import { SqliteOptions } from './SqliteOptions';
/**
 * Adapter for React Native Quick SQLite
 */
export type OPSQLiteAdapterOptions = {
    name: string;
    dbLocation?: string;
    sqliteOptions?: SqliteOptions;
};
export declare class OPSQLiteDBAdapter extends BaseObserver<DBAdapterListener> implements DBAdapter {
    protected options: OPSQLiteAdapterOptions;
    name: string;
    protected locks: Lock;
    protected initialized: Promise<void>;
    protected readConnections: Array<{
        busy: boolean;
        connection: OPSQLiteConnection;
    }> | null;
    protected writeConnection: OPSQLiteConnection | null;
    private readQueue;
    private abortController;
    constructor(options: OPSQLiteAdapterOptions);
    protected init(): Promise<void>;
    protected openConnection(filenameOverride?: string): Promise<OPSQLiteConnection>;
    private openDatabase;
    private loadAdditionalExtensions;
    private loadPowerSyncExtension;
    close(): Promise<void>;
    readLock<T>(fn: (tx: OPSQLiteConnection) => Promise<T>, options?: DBLockOptions): Promise<T>;
    private processQueue;
    writeLock<T>(fn: (tx: OPSQLiteConnection) => Promise<T>, options?: DBLockOptions): Promise<T>;
    readTransaction<T>(fn: (tx: Transaction) => Promise<T>, options?: DBLockOptions): Promise<T>;
    writeTransaction<T>(fn: (tx: Transaction) => Promise<T>, options?: DBLockOptions): Promise<T>;
    getAll<T>(sql: string, parameters?: any[]): Promise<T[]>;
    getOptional<T>(sql: string, parameters?: any[]): Promise<T | null>;
    get<T>(sql: string, parameters?: any[]): Promise<T>;
    execute(query: string, params?: any[]): Promise<QueryResult>;
    executeRaw(query: string, params?: any[]): Promise<any[][]>;
    executeBatch(query: string, params?: any[][]): Promise<QueryResult>;
    protected internalTransaction<T>(connection: OPSQLiteConnection, fn: (tx: Transaction) => Promise<T>): Promise<T>;
    refreshSchema(): Promise<void>;
}
//# sourceMappingURL=OPSqliteAdapter.d.ts.map